@@ -1,5 +1,5 @@
 from .adjust import (exposure, shadows)
 from .conversion import (as_dtype)
 from .correction import (flatfield_correction, gamma_correction, normalize)
-from .enhance import (clahe, clip, stretch_percentile, stretch_binned_percentile)
+from .enhance import (clahe, clip, stretch, stretch_percentile, stretch_binned_percentile)
 
