@@ -4,6 +4,12 @@ from typing import List
 
 
 def write(file: Path, tags: List[str]):
+    """Write image metadata tags to an image file using ExifTool. Existing file
+    will be overwritten.
+
+    :param file: Path to image file.
+    :param tags: List of ExifTool tag assignment strings.
+    """
     # Setup metadata copy
     cmd = ['exiftool', '-q', '-overwrite_original', str(file)]
 
@@ -16,7 +22,13 @@ def write(file: Path, tags: List[str]):
 
 def copy_all(src: Path, dest: Path, extra_tags: List[str] = None,
              overwrite=True):
-    """Copy tag metadata from src to dest"""
+    """Copy tag metadata from source image to destination image.
+
+    :param src: Path to image file containing source metadata.
+    :param dest: Path to destination image file.
+    :param extra_tags: If provided, write additional tags to :code:`dest`.
+    :param overwrite: If :code:`True`, overwrite the destination image file.
+    """
     # Setup metadata copy
     cmd = ['exiftool', '-q']
 
