@@ -10,6 +10,11 @@ _ROI_REGEX = re.compile(_ROI_REGEX)
 
 
 def parse_roi_params(roi_str: str):
+    """ Parse an image region-of-interest string of the form :code:`WxH+X+Y`.
+
+    :param roi_str: ROI string
+    :return: ROI dataclass
+    """
     # ROI return value
     @dataclass
     class ROI:
